==> koin_flutter-0.9.4.tar.gz: test/widgets/bloc_extension/pages.dart <==
import 'package:flutter/material.dart';
import 'package:koin/koin.dart';
import 'package:koin_flutter/koin_disposable.dart';
import 'package:koin_flutter/koin_flutter.dart';

abstract class BlocBase {
  void dispose();
}

class Bloc extends BlocBase with Disposable {
  bool isDisposed = false;

  @override
  void dispose() {
    isDisposed = true;
  }
}

class BlocComponentTest extends KoinComponent {
  Bloc blocX;

  BlocComponentTest() {
    blocX = get();
  }
}

class BlocComponentMixinTest with KoinComponentMixin {
  Bloc blocX;

  BlocComponentMixinTest() {
    blocX = get();
  }
}


final buttonKey = UniqueKey();
final fisrtPage = UniqueKey();
final secondPageKey = UniqueKey();

class ScopeWidget extends StatefulWidget {
  @override
  ScopeWidgetState createState() => ScopeWidgetState();
}

class ScopeWidgetState extends State<ScopeWidget> with ScopeStateMixin {
  Bloc bloc;

  @override
  void initState() {
    bloc = currentScope.get<Bloc>();
    super.initState();
  }

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      key: fisrtPage,
      body: Container(),
      bottomNavigationBar: GestureDetector(
        key: buttonKey,
        child: Icon(Icons.add),
        onTap: () {
          Navigator.pushAndRemoveUntil(context,
              MaterialPageRoute(builder: (BuildContext context) {
            return SecondPage();
          }), (t) => false);
        },
      ),
    );
  }
}

class WidgetNotUseScope extends StatefulWidget {
  @override
  WidgetNotUseScopeState createState() => WidgetNotUseScopeState();
}

class WidgetNotUseScopeState extends State<WidgetNotUseScope>
    with ScopeStateMixin {
  @override
  Widget build(BuildContext context) {
    return Scaffold(
      key: fisrtPage,
      body: Container(),
      bottomNavigationBar: GestureDetector(
        key: buttonKey,
        child: Icon(Icons.add),
        onTap: () {
          Navigator.pushAndRemoveUntil(context,
              MaterialPageRoute(builder: (BuildContext context) {
            return SecondPage();
          }), (router) => false);
        },
      ),
    );
  }
}

class SecondPage extends StatefulWidget {
  @override
  _SecondPageState createState() => _SecondPageState();
}

class _SecondPageState extends State<SecondPage> {
  @override
  Widget build(BuildContext context) {
    return Scaffold(
      key: secondPageKey,
      body: Container(
        child: Column(
          children: <Widget>[
            Text("Test"),
          ],
        ),
      ),
    );
  }
}

class UseScopeWidget extends StatefulWidget {
  @override
  UseScopeWidgetState createState() => UseScopeWidgetState(scope.get<Bloc>());
}

class UseScopeWidgetState extends State<UseScopeWidget> with ScopeStateMixin {
  final Bloc myBloc;

  UseScopeWidgetState(this.myBloc);

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      key: fisrtPage,
      body: Container(),
      bottomNavigationBar: GestureDetector(
        key: buttonKey,
        child: Icon(Icons.add),
        onTap: () {
          Navigator.pushAndRemoveUntil(context,
              MaterialPageRoute(builder: (BuildContext context) {
            return SecondPage();
          }), (t) => false);
        },
      ),
    );
  }
}

class UseScopeExtensionWidget extends StatefulWidget {
  @override
  UseScopeExtensionWidgetState createState() => UseScopeExtensionWidgetState();
}

class UseScopeExtensionWidgetState extends State<UseScopeExtensionWidget> {
  Bloc myBloc;

  @override
  void initState() {
    super.initState();
    myBloc = currentScope.get();
  }

  // Close the scope manually.
  @override
  void dispose() {
    currentScope.close();
    super.dispose();
  }

  UseScopeExtensionWidgetState();

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      key: fisrtPage,
      body: Container(),
      bottomNavigationBar: GestureDetector(
        key: buttonKey,
        child: Icon(Icons.add),
        onTap: () {
          Navigator.pushAndRemoveUntil(context,
              MaterialPageRoute(builder: (BuildContext context) {
            return SecondPage();
          }), (t) => false);
        },
      ),
    );
  }
}

==> koin_flutter-0.10.0.tar.gz: test/widgets/bloc_extension/pages.dart <==
import 'package:flutter/material.dart';
import 'package:koin/koin.dart';
import 'package:koin_flutter/koin_disposable.dart';
import 'package:koin_flutter/koin_flutter.dart';

abstract class BlocBase {
  void dispose();
}

class Bloc extends BlocBase implements Disposable {
  bool isDisposed = false;

  @override
  void dispose() {
    isDisposed = true;
  }
}

class BlocComponentTest extends KoinComponent {
  BlocComponentTest() {
    blocX = get();
  }
  Bloc blocX;
}

class BlocComponentMixinTest with KoinComponentMixin {
  BlocComponentMixinTest() {
    blocX = get();
  }
  Bloc blocX;
}

final buttonKey = UniqueKey();
final fisrtPage = UniqueKey();
final secondPageKey = UniqueKey();

class ScopeWidget extends StatefulWidget with HotRestartScopeMixin {
  @override
  ScopeWidgetState createState() => ScopeWidgetState();

  @override
  Widget get route => ScopeWidget();
}

class ScopeWidgetState extends State<ScopeWidget> with ScopeStateMixin {
  Bloc bloc;

  @override
  void initState() {
    bloc = currentScope.get<Bloc>();
    super.initState();
  }

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      key: fisrtPage,
      body: Container(),
      bottomNavigationBar: GestureDetector(
        key: buttonKey,
        child: Icon(Icons.add),
        onTap: () {
          Navigator.pushAndRemoveUntil(context,
              MaterialPageRoute(builder: (context) {
            return SecondPage();
          }), (t) => false);
        },
      ),
    );
  }
}

class WidgetNotUseScope extends StatefulWidget with HotRestartScopeMixin {
  @override
  WidgetNotUseScopeState createState() => WidgetNotUseScopeState();

  @override
  Widget get route => WidgetNotUseScope();
}

class WidgetNotUseScopeState extends State<WidgetNotUseScope>
    with ScopeStateMixin {
  @override
  Widget build(BuildContext context) {
    return Scaffold(
      key: fisrtPage,
      body: Container(),
      bottomNavigationBar: GestureDetector(
        key: buttonKey,
        child: Icon(Icons.add),
        onTap: () {
          Navigator.pushAndRemoveUntil(context,
              MaterialPageRoute(builder: (context) {
            return SecondPage();
          }), (router) => false);
        },
      ),
    );
  }
}

class SecondPage extends StatefulWidget {
  @override
  _SecondPageState createState() => _SecondPageState();
}

class _SecondPageState extends State<SecondPage> {
  @override
  Widget build(BuildContext context) {
    return Scaffold(
      key: secondPageKey,
      body: Container(
        child: Column(
          children: <Widget>[
            Text("Test"),
          ],
        ),
      ),
    );
  }
}

class UseScopeWidget extends StatefulWidget with HotRestartScopeMixin {
  @override
  UseScopeWidgetState createState() => UseScopeWidgetState(scope.get<Bloc>());

  @override
  Widget get route => UseScopeWidget();
}

class UseScopeWidgetState extends State<UseScopeWidget> with ScopeStateMixin {
  UseScopeWidgetState(this.myBloc);

  final Bloc myBloc;

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      key: fisrtPage,
      body: Container(),
      bottomNavigationBar: GestureDetector(
        key: buttonKey,
        child: Icon(Icons.add),
        onTap: () {
          Navigator.pushAndRemoveUntil(context,
              MaterialPageRoute(builder: (context) {
            return SecondPage();
          }), (t) => false);
        },
      ),
    );
  }
}

class UseScopeExtensionWidget extends StatefulWidget {
  @override
  UseScopeExtensionWidgetState createState() => UseScopeExtensionWidgetState();
}

class UseScopeExtensionWidgetState extends State<UseScopeExtensionWidget> {
  Bloc myBloc;

  @override
  void initState() {
    super.initState();
    myBloc = currentScope.get();
  }

  // Close the scope manually.
  @override
  void dispose() {
    currentScope.close();
    super.dispose();
  }

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      key: fisrtPage,
      body: Container(),
      bottomNavigationBar: GestureDetector(
        key: buttonKey,
        child: Icon(Icons.add),
        onTap: () {
          Navigator.pushAndRemoveUntil(context,
              MaterialPageRoute(builder: (context) {
            return SecondPage();
          }), (t) => false);
        },
      ),
    );
  }
}
